@@ -8,7 +8,7 @@ ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
     QWidget(parent),
     ui(new Ui::ProfileChangerWidget)
 {
-    syslog(LOG_WARNING, "profile-changer-widget.cpp setupui");
+    qWarning("profile-changer-widget.cpp setupui");
     ui->setupUi(this);
 //    this->setAttribute(Qt::WA_TranslucentBackground);
 //    if (!QSettings().contains("profilechangerwidget/width"))
@@ -16,9 +16,9 @@ ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
 //    if (!QSettings().contains("profilechangerwidget/height"))
 //        QSettings().setValue("profilechangerwidget/height", 48);
 
-//    syslog(LOG_WARNING, "profile-changer-widget connect onChangeProfileClicked");
+//    qWarning("profile-changer-widget connect onChangeProfileClicked");
 //    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
-//    syslog(LOG_WARNING, "profile-changer-widget connect reload");
+//    qWarning("profile-changer-widget connect reload");
 //    this->reloadSettings();
 }
 
